using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using AutoMapper;
using Dapper;
using Datory;
using GxPress.Common.AppOptions;
using GxPress.Common.Tools;
using GxPress.Repository.Interface.SmsLog;
using Microsoft.Extensions.Options;

namespace GxPress.Repository.Implement.SmsLog
{
    public class SmsLogRepository : ISmsLogRepository
    {
        private readonly Repository<Entity.SmsLog> _repository;
        private readonly IMapper _mapper;
        private readonly string _connectionString;
        private readonly string _databaseTypeStr;
        public SmsLogRepository(IOptionsMonitor<DatabaseOptions> dbOptionsAccessor, IMapper mapper)
        {
            _databaseTypeStr = dbOptionsAccessor.CurrentValue.DatabaseType;
            _connectionString = dbOptionsAccessor.CurrentValue.ConnectionString;
            var databaseType = StringUtils.ToEnum<DatabaseType>(dbOptionsAccessor.CurrentValue.DatabaseType, DatabaseType.MySql);
            var database = new Database(databaseType, dbOptionsAccessor.CurrentValue.ConnectionString);
            _repository = new Repository<Entity.SmsLog>(database);
            _mapper = mapper;
        }

        public IDatabase Database => _repository.Database;
        public string TableName => _repository.TableName;
        public List<TableColumn> TableColumns => _repository.TableColumns;

        public async Task<bool> InsertAsync(IEnumerable<Entity.SmsLog> smsLogs)
        {
            var guId = System.Guid.NewGuid().ToString();
            var nowTime = DateTime.Now.ToString();
            string sql = $@"INSERT INTO `ccpph`.`tede_sms_log`
                                        (`Guid`,
                                        `CreatedDate`,
                                        `LastModifiedDate`,
                                        `Phone`,
                                        `SourceId`,
                                        `SourceType`,
                                        `IsSend`,
                                        `Message`)
                                        VALUES";
            foreach (var item in smsLogs)
            {
                var isSend = item.IsSend ? 1 : 0;
                sql += $@"(
                                        '{guId}',
                                        '{nowTime}',
                                        '{nowTime}',
                                        '{item.Phone}',
                                         {item.SourceId},
                                         {item.SourceType},
                                         {isSend},
                                        '{item.Message}'),";
            }
            sql = sql.Remove(sql.Length - 1, 1);
            var databaseType = StringUtils.ToEnum<DatabaseType>(_databaseTypeStr, DatabaseType.MySql);
            var database = new Database(databaseType, _connectionString);
            var connection = database.GetConnection();
            return await connection.ExecuteAsync(sql) > 0;
        }

    }
}